@@ -143,11 +143,11 @@ class Topology(object):
 
     Examples
     --------
-    >>> topology = md.load('example.pdb').topology            # doctest: +SKIP
-    >>> print(topology)                                       # doctest: +SKIP
+    >>> topology = md.load('example.pdb').topology
+    >>> print(topology)
     <mdtraj.Topology with 1 chains, 3 residues, 22 atoms, 21 bonds at 0x105a98e90>
-    >>> table, bonds = topology.to_dataframe()                # doctest: +SKIP
-    >>> print(table.head())                                   # doctest: +SKIP
+    >>> table, bonds = topology.to_dataframe()
+    >>> print(table.head())
        serial name element  resSeq resName  chainID
     0       0   H1       H       0     CYS        0
     1       1  CH3       C       0     CYS        0
@@ -155,15 +155,15 @@ class Topology(object):
     3       3   H3       H       0     CYS        0
     4       4    C       C       0     CYS        0
     >>> # rename residue "CYS" to "CYSS"
-    >>> table[table['residue'] == 'CYS']['residue'] = 'CYSS'  # doctest: +SKIP
-    >>> print(table.head())                                   # doctest: +SKIP
+    >>> table[table['residue'] == 'CYS']['residue'] = 'CYSS'
+    >>> print(table.head())
        serial name element  resSeq resName   chainID
     0       0   H1       H       0     CYSS        0
     1       1  CH3       C       0     CYSS        0
     2       2   H2       H       0     CYSS        0
     3       3   H3       H       0     CYSS        0
     4       4    C       C       0     CYSS        0
-    >>> t2 = md.Topology.from_dataframe(table, bonds)         # doctest: +SKIP
+    >>> t2 = md.Topology.from_dataframe(table, bonds)
     """
 
     _standardBonds = {}
@@ -835,6 +835,8 @@ class Residue(object):
         """Get the number of atoms in this Residue"""
         return len(self._atoms)
 
+    def  __str__(self):
+        return '%s%s' % (self.name, self.resSeq)
 
 class Atom(object):
     """An Atom object represents a residue within a Topology.
@@ -881,3 +883,6 @@ class Atom(object):
     def __hash__(self):
         """ A quick comparison. """
         return self.index
+
+    def __str__(self):
+        return '%s-%s' % (self.residue, self.name)
